// Base class MabaImageButton

function MabaImageButton(buttonCssId, buttonFolder, buttonFilename, buttonDownFilename)
{
	this.buttonFolder = buttonFolder;
	this.buttonFilename = buttonFilename;
	this.buttonDownFilename = buttonDownFilename;
	this.buttonCssId = buttonCssId;

	this.enabled = true;
	this.buttonClicked = false;
	this.mouseDownInButton = false;

	var thisobj = this;
	this.mouseMoveCallback = function (event) { thisobj.mouseMove(event); }
	this.mouseUpCallback = function (event) { thisobj.mouseUp(event); }
	this.mouseOverCallback = function (event) { thisobj.mouseOver(event); }
	this.mouseOutCallback = function (event) { thisobj.mouseOut(event); }
}

MabaImageButton.prototype.changeImageFolder = function (buttonFolder)
{
	this.buttonFolder = buttonFolder;
	$(this.buttonCssId).src = this.buttonFolder + '/' + this.buttonFilename;
}

MabaImageButton.prototype.setEnabled = function (state)
{
	this.enabled = state;
	var button = $(this.buttonCssId);
	if (button.style) {
		button.style.opacity = (this.enabled ? 1.0 : 0.2);
	}
}

MabaImageButton.prototype.pulseButton = function()
{
	setTimeout ('MabaImageButton.prototype.pulseButtonTimeout("' + this.buttonCssId + '",1);', 2);
}
MabaImageButton.prototype.pulseButtonTimeout = function(cssname, count)
{
	$(cssname).style.opacity = (count%2) ? 0.5 : 1.0;
	if (count > 0) {
		setTimeout ('MabaImageButton.prototype.pulseButtonTimeout("' + cssname + '",' + (count-1) + ');', 300);
	}
}


MabaImageButton.prototype.symbolTyping = function (event)
{
	this.buttonClicked = false;
}

MabaImageButton.prototype.symbolKeyPress = function (event)
{
	switch (event.keyCode)
	{
		case 13: // return
		case 3:  // enter
			this.buttonClicked = true;
			break;
	}
}


MabaImageButton.prototype.setButtonClicked = function (event, state)
{
	this.buttonClicked = state;
}

MabaImageButton.prototype.isButtonClicked = function (event)
{
	return this.buttonClicked;
}


MabaImageButton.prototype.mouseDown = function (event)
{
	if (!this.enabled) {return;}

	var button = $(this.buttonCssId);
	
	button.src = this.buttonFolder + '/' + this.buttonDownFilename;

	document.addEventListener("mousemove", this.mouseMoveCallback, true);
	document.addEventListener("mouseup", this.mouseUpCallback, true);
	button.addEventListener("mouseover", this.mouseOverCallback, true);
	button.addEventListener("mouseout", this.mouseOutCallback, true);	
	
	this.mouseDownInButton = true;
	
	event.stopPropagation();
	event.preventDefault();
}


MabaImageButton.prototype.mouseMove = function (event)
{
	event.stopPropagation();
	event.preventDefault();
}

MabaImageButton.prototype.mouseOver = function (event)
{
	this.mouseDownInButton = true;
	$(this.buttonCssId).src = this.buttonFolder + '/' + this.buttonDownFilename;
	event.stopPropagation();
	event.preventDefault();
}

MabaImageButton.prototype.mouseOut = function (event)
{
	$(this.buttonCssId).src = this.buttonFolder + '/' + this.buttonFilename;
	this.mouseDownInButton = false;

	event.stopPropagation();
	event.preventDefault();
}

MabaImageButton.prototype.mouseUp = function (event)
{
	var button = $(this.buttonCssId);

	document.removeEventListener("mousemove", this.mouseMoveCallback, true);
	document.removeEventListener("mouseup", this.mouseUpCallback, true);	
	button.removeEventListener("mouseover", this.mouseOverCallback, true);
	button.removeEventListener("mouseout", this.mouseOutCallback, true);

	button.src = this.buttonFolder + '/' + this.buttonFilename;
	if (this.mouseDownInButton) {
		this.setButtonClicked(event, true);
	}

	event.stopPropagation();
	event.preventDefault();
}



// ------- Instance MabaAddImageButton with specialized methods.

MabaAddImageButton.prototype = new MabaImageButton();
MabaAddImageButton.prototype.constructor = MabaAddImageButton;
MabaAddImageButton.prototype.parent = MabaImageButton.prototype;


function MabaAddImageButton(imageFolder) {
	this.prototype = new MabaImageButton();
	this.parent = MabaImageButton.prototype;

	this.parent.constructor.call(this, 'addbutton', imageFolder, 'addbutton.png', 'addbuttondown.png');

	this.symbolTyping = function (event) {
		this.parent.symbolTyping.call(this, event);
		// if we are typing in the input then we cannnot have just clicked the add button
		this.lastValidEntry = null;
	}

	this.symbolKeyPress = function (event) {
		this.parent.symbolKeyPress.call(this, event);
		this.callout();
	}

	this.setButtonClicked = function (event, state)
	{
		this.parent.setButtonClicked.call(this, event, state);
		this.callout();
	}

	this.callout = function () {
		if (this.buttonClicked)	{
			symbolChanged();
		}
	}
}


// ------- Instance MabaRenameImageButton with specialized methods.

MabaRenameImageButton.prototype = new MabaImageButton();
MabaRenameImageButton.prototype.constructor = MabaRenameImageButton;
MabaRenameImageButton.prototype.parent = MabaImageButton.prototype;

function MabaRenameImageButton(imageFolder) {
	this.prototype = new MabaImageButton();
	this.parent = MabaImageButton.prototype;

	this.parent.constructor.call(this, 'renamebutton', imageFolder, 'renamebutton.png', 'renamebuttondown.png');

	this.symbolTyping = function (event) {
		this.parent.symbolTyping.call(this, event);
		// if we are typing in the input then we cannnot have just clicked the add button
		// this.lastValidEntry = null;
	}

	this.symbolKeyPress = function (event) {
		this.parent.symbolKeyPress.call(this, event);
		this.callout();
	}

	this.setButtonClicked = function (event, state)
	{
		this.parent.setButtonClicked.call(this, event, state);
		this.callout();
	}

	this.callout = function () {
		if (this.buttonClicked) {
			renameButtonClicked();
		}
		this.buttonClicked = false;
	}
}

// ------- Instance MabaRemoveImageButton with specialized methods.

MabaRemoveImageButton.prototype = new MabaImageButton();
MabaRemoveImageButton.prototype.constructor = MabaRemoveImageButton;
MabaRemoveImageButton.prototype.parent = MabaImageButton.prototype;

function MabaRemoveImageButton(imageFolder) {
	this.prototype = new MabaImageButton();
	this.parent = MabaImageButton.prototype;

	this.parent.constructor.call(this, 'removebutton', imageFolder, 'removebutton.png', 'removebuttondown.png');

	this.setButtonClicked = function (event, state)
	{
		this.parent.setButtonClicked.call(this, event, state);
		if (this.buttonClicked) {
			removeButtonClicked();
		}
		this.buttonClicked = false;
	}
}
